==> AsposeCellsCloud-CellsApi-25.10.tar.gz: AsposeCellsCloud-CellsApi-25.10/docs/model/PptxSaveOptions.md <==
# AsposeCellsCloud::Object::PptxSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::PptxSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**IgnoreHiddenRows** | **boolean** |  |
**AdjustFontSizeForRowType** | **string** |  |
**ExportViewType** | **string** |  |
**DefaultFont** | **string** |  |
**CheckWorkbookDefaultFont** | **boolean** |  |
**CheckFontCompatibility** | **boolean** |  |
**IsFontSubstitutionCharGranularity** | **boolean** |  |
**OnePagePerSheet** | **boolean** |  |
**AllColumnsInOnePagePerSheet** | **boolean** |  |
**IgnoreError** | **boolean** |  |
**OutputBlankPageWhenNothingToPrint** | **boolean** |  |
**PageIndex** | **int** |  |
**PageCount** | **int** |  |
**PrintingPageType** | **string** |  |
**GridlineType** | **string** |  |
**TextCrossType** | **string** |  |
**DefaultEditLanguage** | **string** |  |
**EmfRenderSetting** | **string** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |
**CheckExcelRestriction** | **boolean** |  |
**EncryptDocumentProperties** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/PptxSaveOptions.md <==
# AsposeCellsCloud::Object::PptxSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::PptxSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**IgnoreHiddenRows** | **boolean** |  |
**AdjustFontSizeForRowType** | **string** |  |
**ExportViewType** | **string** |  |
**DefaultFont** | **string** |  |
**CheckWorkbookDefaultFont** | **boolean** |  |
**CheckFontCompatibility** | **boolean** |  |
**IsFontSubstitutionCharGranularity** | **boolean** |  |
**OnePagePerSheet** | **boolean** |  |
**AllColumnsInOnePagePerSheet** | **boolean** |  |
**IgnoreError** | **boolean** |  |
**OutputBlankPageWhenNothingToPrint** | **boolean** |  |
**PageIndex** | **int** |  |
**PageCount** | **int** |  |
**PrintingPageType** | **string** |  |
**GridlineType** | **string** |  |
**TextCrossType** | **string** |  |
**DefaultEditLanguage** | **string** |  |
**EmfRenderSetting** | **string** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |
**CheckExcelRestriction** | **boolean** |  |
**EncryptDocumentProperties** | **boolean** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
